/* pppd/pppdconf.h.  Generated from pppdconf.h.in by configure.  */
/* 
 * Copyright (c) 2022 Eivind Næss. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The name(s) of the authors of this software must not be used to
 *    endorse or promote products derived from this software without
 *    prior written permission.
 *
 * THE AUTHORS OF THIS SOFTWARE DISCLAIM ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS, IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/*
 * This file is generated by configure and sets the features enabled
 *   in pppd when configured.
 */

#ifndef PPP_PPPDCONF_H
#define PPP_PPPDCONF_H

/* Have Microsoft CHAP support */
#define PPP_WITH_CHAPMS 1

/* Have Microsoft LAN Manager support */
/* #undef PPP_WITH_MSLANMAN */

/* Have Microsoft MPPE support */
#define PPP_WITH_MPPE 1

/* Have multilink support */
/* #undef PPP_WITH_MULTILINK */

/* Have packet activity filter support */
#define PPP_WITH_FILTER 1

/* Have support for loadable plugins */
#define PPP_WITH_PLUGINS 1

/* Have Callback Protocol support */
/* #undef PPP_WITH_CBCP */

/* Include TDB support */
/* #undef PPP_WITH_TDB */

/* Have IPv6 Control Protocol */
#define PPP_WITH_IPV6CP 1

/* Support for Pluggable Authentication Modules */
/* #undef PPP_WITH_PAM */

/* Have EAP-SRP authentication support */
/* #undef PPP_WITH_SRP */

/* Have EAP-TLS authentication support */
#define PPP_WITH_EAPTLS 1

/* Have PEAP authentication support */
#define PPP_WITH_PEAP 1

/* The pppd version */
#define PPPD_VERSION "2.5.0"

#endif
